#[repr(i32)]pub enum PermissionUpdateType {
Unspecified = 0,
AddMember = 1,
RemoveMember = 2,
AddAdmin = 3,
RemoveAdmin = 4,
UpdateMetadata = 5,
}Expand description
Type of Permission to Update
Variants
Implementations
Sourceimpl PermissionUpdateType
impl PermissionUpdateType
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of PermissionUpdateType.
Sourcepub fn from_i32(value: i32) -> Option<PermissionUpdateType>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<PermissionUpdateType>
Use the TryFrom<i32> implementation instead
Converts an i32 to a PermissionUpdateType, or None if value is not a valid variant.
Sourceimpl PermissionUpdateType
impl PermissionUpdateType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.